[PATCH] D107440: [llvm][MC] Disable cfi-version test for Windows on Arm

David Spickett via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Aug 4 03:28:01 PDT 2021


DavidSpickett created this revision.
Herald added subscribers: pengfei, kristof.beyls, emaste.
DavidSpickett requested review of this revision.
Herald added subscribers: llvm-commits, MaskRay.
Herald added a project: LLVM.

Like Windows on x86-64, Windows on arm64 uses structured
exception handling, so we don't emit .debug_frame.

See:
https://docs.microsoft.com/en-us/cpp/build/arm64-exception-handling?view=msvc-160


Repository:
  rG LLVM Github Monorepo

https://reviews.llvm.org/D107440

Files:
  llvm/test/MC/ELF/cfi-version.ll
  llvm/test/lit.cfg.py


Index: llvm/test/MC/ELF/cfi-version.ll
===================================================================
--- llvm/test/MC/ELF/cfi-version.ll
+++ llvm/test/MC/ELF/cfi-version.ll
@@ -6,7 +6,7 @@
 ; PR46647
 ; XFAIL: arm64-apple
 
-; .debug_frame is not emitted for targeting Windows x64.
+; .debug_frame is not emitted for targeting Windows x64 or arm64.
 ; REQUIRES: debug_frame
 ; REQUIRES: default_triple
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D107440.364028.patch
Type: text/x-patch
Size: 1044 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20210804/d01cd9f4/attachment.bin>


More information about the llvm-commits mailing list
Index: llvm/test/lit.cfg.py
===================================================================
--- llvm/test/lit.cfg.py
+++ llvm/test/lit.cfg.py
@@ -370,8 +370,8 @@
         if 'hw.optional.fma: 1' in result:
             config.available_features.add('fma3')
 
-# .debug_frame is not emitted for targeting Windows x64.
-if not re.match(r'^x86_64.*-(windows-gnu|windows-msvc)', config.target_triple):
+# .debug_frame is not emitted for targeting Windows x64 or arm64.
+if not re.match(r'^(x86_64|arm64).*-(windows-gnu|windows-msvc)', config.target_triple):
     config.available_features.add('debug_frame')
 
 if config.have_libxar: